<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


require_once ("../bootstrap/bootstrap.php");


$database_logs = Database_Logs::getInstance ();


// Security: The script runs from the cli SAPI only.
if (php_sapi_name () != "cli") {
  $database_logs->log ("Fatal: export/web0.php only runs through the cli SAPI", Filter_Roles::ADMIN_LEVEL);
  die;
}


ignore_user_abort (true);
set_time_limit (0);


// The input parameters.
$bible = $argv [1];
$force = $argv [2];


// Create folders for the web export.
$directory = Export_Logic::webDirectory ($bible);
if (!file_exists ($directory)) mkdir ($directory, 0777, true);


// Filenames for the web file and stylesheet.
$indexFile = "$directory/index.html";
$index00 = "$directory/00_index.html";
$filecss = "$directory/stylesheet.css";


// If no update is forced, if the files are already there, bail out.
if (!$force) {
  if (!file_exists ($indexFile)) $force = true;
  if (!file_exists ($index00)) $force = true;
  if (!file_exists ($filecss)) $force = true;
}
if (!$force) return;


$database_config_general = Database_Config_General::getInstance ();
$database_bibles = Database_Bibles::getInstance ();
$database_books = Database_Books::getInstance ();


$stylesheet = $database_config_general->getExportStylesheet ();


// Create stylesheet.
$styles_sheets = new Styles_Sheets ();
$styles_sheets->create ($stylesheet, $filecss, false, true);


$backLinkPath = Export_Logic::webBackLinkDirectory ($bible);


// Main index file.
$html_text_rich_bible_index = new Html_Text ($bible);
// On top are the breadcrumbs, starting with a clickable Bible name.
$htmlHeader = new Html_Header ($html_text_rich_bible_index);
$htmlHeader->searchBackLink ($backLinkPath . Filter_Paths::htmlFileNameBible (), gettext ("Go back to Bible"));
$htmlHeader->create (array (array ($bible, Filter_Paths::htmlFileNameBible ())));


// Prepare for the list of books in de html index file.
$html_text_rich_bible_index->newParagraph ("navigationbar");
$html_text_rich_bible_index->addText (" |");


// Go through the Bible books.
$books = $database_bibles->getBooks ($bible);
foreach ($books as $book) {


  // Add this book to the main web index.
  $html_text_rich_bible_index->addLink ($html_text_rich_bible_index->currentPDomElement,  Filter_Paths::htmlFileNameBible ("", $book), "", $database_books->getEnglishFromId ($book), "", " " . $database_books->getEnglishFromId ($book) . " ");
  $html_text_rich_bible_index->addText ("|");


}


// Save index file for the interlinked web export.
$database_logs->log ("exports: Create index file for interlinked Web");
$html_text_rich_bible_index->save ($indexFile);
$html_text_rich_bible_index->save ($index00);


// Lens image supporting search.
copy ("../webbible/lens.png", "$directory/lens.png");



$database_logs->log (gettext ("Web export index") . " $bible", Filter_Roles::TRANSLATOR_LEVEL);


?>
